@@ -9,6 +9,7 @@ all_packages = (
     # 'misc_commands',
     'owner_only',
     'presence_auto_updater',
-    'application_command_handler',
+    # 'application_command_handler',
     'interaction_handler',
+    # 'button_command_redirect',
 )
