@@ -24,10 +24,10 @@ class ErrorHandler(vbu.Cog):
             (commands.UnexpectedQuoteError, commands.InvalidEndOfQuotedStringError, commands.ExpectedClosingQuoteError),
             lambda ctx, error: "The quotes in your message have been done incorrectly."
         ),
-        (
-            vbu.checks.cooldown.NoRaiseCommandOnCooldown,
-            lambda ctx, error: None
-        ),
+        # (
+        #     vbu.checks.cooldown.NoRaiseCommandOnCooldown,
+        #     lambda ctx, error: None
+        # ),
         (
             commands.CommandOnCooldown,
             lambda ctx, error: f"You can't use this command again for another {vbu.TimeValue(error.retry_after).clean_spaced}."
@@ -40,18 +40,18 @@ class ErrorHandler(vbu.Cog):
             commands.NSFWChannelRequired,
             lambda ctx, error: f"You can only run this command in channels set as NSFW. {'You can set channels as NSFW in their channel settings.' if ctx.channel.permissions_for(ctx.author).manage_channels else ''}"
         ),
-        (
-            vbu.errors.BotNotInGuild,
-            lambda ctx, error: "The bot needs to be in the guild for you to run this command."
-        ),
-        (
-            vbu.errors.IsSlashCommand,
-            lambda ctx, error: "This command cannot be run as a slash command."
-        ),
-        (
-            vbu.errors.IsNotSlashCommand,
-            lambda ctx, error: "This command can only be run as a slash command."
-        ),
+        # (
+        #     vbu.errors.BotNotInGuild,
+        #     lambda ctx, error: "The bot needs to be in the guild for you to run this command."
+        # ),
+        # (
+        #     vbu.errors.IsSlashCommand,
+        #     lambda ctx, error: "This command cannot be run as a slash command."
+        # ),
+        # (
+        #     vbu.errors.IsNotSlashCommand,
+        #     lambda ctx, error: "This command can only be run as a slash command."
+        # ),
         (
             commands.DisabledCommand,
             lambda ctx, error: "This command has been disabled."
@@ -197,21 +197,18 @@ class ErrorHandler(vbu.Cog):
         instead. If it fails that too, it just stays silent.
         """
 
-        ephemeral = ctx.is_interaction and self.bot.config.get("ephemeral_error_messages", True)
+        ephemeral = ctx.supports_ephemeral and self.bot.config.get("ephemeral_error_messages", True)
         try:
             return await ctx.send(
                 text,
                 allowed_mentions=discord.AllowedMentions.none(),
                 ephemeral=ephemeral,
-                wait=False,
             )
         except discord.Forbidden:
             try:
                 return await ctx.author.send(
                     author_text or text,
                     allowed_mentions=discord.AllowedMentions.none(),
-                    ephemeral=ephemeral,
-                    wait=False,
                 )
             except discord.Forbidden:
                 pass
@@ -262,7 +259,7 @@ class ErrorHandler(vbu.Cog):
                 break
 
         # See if they're tryina fuck me up
-        if output is not None and output in ctx.message.content and isinstance(error, commands.NotOwner):
+        if output is not None and ctx.message and output in ctx.message.content and isinstance(error, commands.NotOwner):
             output = "\N{UNAMUSED FACE}"
 
         # Send a message based on the output
@@ -289,7 +286,7 @@ class ErrorHandler(vbu.Cog):
         guild_id = ctx.guild.id if ctx.guild else None
         error_text = (
             f"Error `{error}` encountered.\nGuild `{guild_id}`, channel `{ctx.channel.id}`, "
-            f"user `{ctx.author.id}`\n```\n{ctx.message.content}\n```"
+            f"user `{ctx.author.id}`\n```\n{ctx.message.content if ctx.message else '[No message content]'}\n```"
         )
 
         # DM to owners
@@ -302,7 +299,7 @@ class ErrorHandler(vbu.Cog):
         # Ping to the webook
         event_webhook: discord.Webhook = self.bot.get_event_webhook("unhandled_error")
         try:
-            avatar_url = str(self.bot.user.avatar_url)
+            avatar_url = str(self.bot.user.avatar.url)
         except Exception:
             avatar_url = None
         if event_webhook:
