@@ -9,6 +9,7 @@ import traceback
 import time
 import typing
 import inspect
+import importlib
 
 import discord
 from discord.ext import commands
@@ -66,7 +67,7 @@ class OwnerOnly(vbu.Cog, command_attrs={'hidden': True, 'add_slash_command': Fal
     @vbu.command()
     @commands.is_owner()
     @vbu.checks.is_config_set("redis", "enabled")
-    @vbu.bot_has_permissions(send_messages=True, attach_files=True, add_reactions=True)
+    @commands.bot_has_permissions(send_messages=True, attach_files=True, add_reactions=True)
     async def redis(self, ctx: vbu.Context, *, content: str):
         """
         Pings a command to be run over redis.
@@ -85,7 +86,7 @@ class OwnerOnly(vbu.Cog, command_attrs={'hidden': True, 'add_slash_command': Fal
 
     @vbu.command(aliases=['src'])
     @commands.is_owner()
-    @vbu.bot_has_permissions(send_messages=True, attach_files=True, add_reactions=True)
+    @commands.bot_has_permissions(send_messages=True, attach_files=True, add_reactions=True)
     async def source(self, ctx: vbu.Context, *, command_name: str):
         """
         Shows you the source for a given command.
@@ -119,7 +120,7 @@ class OwnerOnly(vbu.Cog, command_attrs={'hidden': True, 'add_slash_command': Fal
 
     @vbu.command(aliases=['pm', 'dm', 'send'])
     @commands.is_owner()
-    @vbu.bot_has_permissions(send_messages=True, add_reactions=True)
+    @commands.bot_has_permissions(send_messages=True, add_reactions=True)
     async def message(self, ctx: vbu.Context, snowflake: int, *, content: str = None):
         """
         DMs a user the given content.
@@ -164,9 +165,9 @@ class OwnerOnly(vbu.Cog, command_attrs={'hidden': True, 'add_slash_command': Fal
 
         # And send our data
         try:
-            await sendable.send(**payload, embeddify=False)
+            await sendable.send(**payload)
         except discord.HTTPException as e:
-            return await ctx.send(f"I couldn't send that message - `{e}`", embeddify=False)
+            return await ctx.send(f"I couldn't send that message - `{e}`")
         await ctx.okay()
 
     def _cleanup_code(self, content):
@@ -201,12 +202,17 @@ class OwnerOnly(vbu.Cog, command_attrs={'hidden': True, 'add_slash_command': Fal
 
     @vbu.command(aliases=['evall', 'eval'])
     @commands.is_owner()
-    @vbu.bot_has_permissions(send_messages=True)
+    @commands.bot_has_permissions(send_messages=True)
     async def ev(self, ctx: vbu.Context, *, content: str = None):
         """
         Evaluates some Python code.
         """
 
+        try:
+            utils = importlib.import_module("cogs.utils", package=None)
+        except ModuleNotFoundError:
+            utils = None
+
         # Make the environment
         env = {
             'bot': self.bot,
@@ -219,6 +225,7 @@ class OwnerOnly(vbu.Cog, command_attrs={'hidden': True, 'add_slash_command': Fal
             'vbu': vbu,
             'discord': discord,
             'commands': commands,
+            'utils': utils,
         }
         # env.update(globals())
 
@@ -243,7 +250,7 @@ class OwnerOnly(vbu.Cog, command_attrs={'hidden': True, 'add_slash_command': Fal
         try:
             exec(code, env)
         except Exception as e:
-            return await ctx.send(f'```py\n{e.__class__.__name__}: {e}\n```', embeddify=False)
+            return await ctx.send(f'```py\n{e.__class__.__name__}: {e}\n```')
 
         # Grab the function we just made and run it
         func = env['func']
@@ -255,7 +262,7 @@ class OwnerOnly(vbu.Cog, command_attrs={'hidden': True, 'add_slash_command': Fal
         except Exception:
             end_time = time.perf_counter()
             stdout_value = stdout.getvalue() or None
-            return await ctx.send(f'```py\n{stdout_value}\n{traceback.format_exc()}\n```', embeddify=False)
+            return await ctx.send(f'```py\n{stdout_value}\n{traceback.format_exc()}\n```')
         end_time = time.perf_counter()
 
         # Oh no it didn't cause an error
@@ -271,7 +278,7 @@ class OwnerOnly(vbu.Cog, command_attrs={'hidden': True, 'add_slash_command': Fal
         if ret is None:
             # It might have printed something
             if stdout_value is not None:
-                await ctx.send(f'```py\n{stdout_value}\n```{self.get_execution_time(end_time, start_time)}', embeddify=False)
+                await ctx.send(f'```py\n{stdout_value}\n```{self.get_execution_time(end_time, start_time)}')
             return
 
         # If the function did return a value
@@ -292,17 +299,11 @@ class OwnerOnly(vbu.Cog, command_attrs={'hidden': True, 'add_slash_command': Fal
         text += self.get_execution_time(end_time, start_time)
 
         # Output to chat
-        if len(text) > 2000:
-            try:
-                return await ctx.send(self.get_execution_time(end_time, start_time), file=discord.File(io.StringIO(result), filename=f"ev.{filetype}"))
-            except discord.HTTPException:
-                return await ctx.send("I don't have permission to attach files here.", embeddify=False)
-        else:
-            return await ctx.send(text, embeddify=False)
+        return await ctx.send(self.get_execution_time(end_time, start_time), file=discord.File(io.StringIO(result), filename=f"ev.{filetype}"))
 
     @vbu.command(aliases=['rld', 'rl'])
     @commands.is_owner()
-    @vbu.bot_has_permissions(send_messages=True)
+    @commands.bot_has_permissions(send_messages=True)
     async def reload(self, ctx: vbu.Context, *cog_name: str):
         """
         Unloads and reloads a cog from the bot.
@@ -392,7 +393,7 @@ class OwnerOnly(vbu.Cog, command_attrs={'hidden': True, 'add_slash_command': Fal
 
     @vbu.command()
     @commands.is_owner()
-    @vbu.bot_has_permissions(send_messages=True)
+    @commands.bot_has_permissions(send_messages=True)
     async def runsql(self, ctx: vbu.Context, *, sql: str):
         """
         Runs a line of SQL into the database.
@@ -415,13 +416,21 @@ class OwnerOnly(vbu.Cog, command_attrs={'hidden': True, 'add_slash_command': Fal
         # See how long our lines are
         for row in rows:
             for header in headers:
-                column_widths[header] = max([column_widths[header], len(str(row[header]))])
+                row_value = row[header]
+                if row_value is None:
+                    continue
+                column_widths[header] = max([column_widths[header], len(repr(row_value))])
 
         # Work out our rows
         for row in rows:
             working = ""
             for header in headers:
-                working += format(str(row[header]), f" <{column_widths[header]}") + "|"
+                row_value = row[header]
+                if row_value is None:
+                    row_display = ""
+                else:
+                    row_display = repr(row_value)
+                working += format(row_display, f" <{column_widths[header]}") + "|"
             lines.append(working[:-1])
 
         # Add on our headers
@@ -435,15 +444,12 @@ class OwnerOnly(vbu.Cog, command_attrs={'hidden': True, 'add_slash_command': Fal
 
         # Send it out
         string_output = '\n'.join(lines)
-        try:
-            await ctx.send(f"```\n{string_output}```", embeddify=False)
-        except discord.HTTPException:
-            file = discord.File(io.StringIO(string_output), filename="runsql.txt")
-            await ctx.send(file=file)
+        file = discord.File(io.StringIO(string_output), filename="runsql.txt")
+        await ctx.send(file=file)
 
     @vbu.group()
     @commands.is_owner()
-    @vbu.bot_has_permissions(send_messages=True)
+    @commands.bot_has_permissions(send_messages=True)
     async def botuser(self, ctx: vbu.Context):
         """
         A parent command for the bot user configuration section.
@@ -453,7 +459,7 @@ class OwnerOnly(vbu.Cog, command_attrs={'hidden': True, 'add_slash_command': Fal
 
     @botuser.command(name='name', aliases=['username'])
     @commands.is_owner()
-    @vbu.bot_has_permissions(send_messages=True)
+    @commands.bot_has_permissions(send_messages=True)
     async def botuser_name(self, ctx: vbu.Context, *, username: str):
         """
         Lets you set the username for the bot account.
@@ -466,7 +472,7 @@ class OwnerOnly(vbu.Cog, command_attrs={'hidden': True, 'add_slash_command': Fal
 
     @botuser.command(name='avatar', aliases=['photo', 'image', 'picture'])
     @commands.is_owner()
-    @vbu.bot_has_permissions(send_messages=True)
+    @commands.bot_has_permissions(send_messages=True)
     async def botuser_avatar(self, ctx: vbu.Context, *, image_url: typing.Optional[str]):
         """
         Lets you set the profile picture of the bot.
@@ -485,7 +491,7 @@ class OwnerOnly(vbu.Cog, command_attrs={'hidden': True, 'add_slash_command': Fal
 
     @botuser.command(name='activity', aliases=['game'])
     @commands.is_owner()
-    @vbu.bot_has_permissions(send_messages=True)
+    @commands.bot_has_permissions(send_messages=True)
     async def botuser_activity(self, ctx: vbu.Context, activity_type: str, *, name: typing.Optional[str]):
         """
         Changes the activity of the bot.
@@ -499,7 +505,7 @@ class OwnerOnly(vbu.Cog, command_attrs={'hidden': True, 'add_slash_command': Fal
 
     @botuser.command(name='status')
     @commands.is_owner()
-    @vbu.bot_has_permissions(send_messages=True)
+    @commands.bot_has_permissions(send_messages=True)
     async def botuser_status(self, ctx: vbu.Context, status: str):
         """
         Changes the online status of the bot.
@@ -510,7 +516,7 @@ class OwnerOnly(vbu.Cog, command_attrs={'hidden': True, 'add_slash_command': Fal
 
     @vbu.command(aliases=['sudo'])
     @commands.is_owner()
-    @vbu.bot_has_permissions(send_messages=True)
+    @commands.bot_has_permissions(send_messages=True)
     async def su(self, ctx, who: discord.User, *, command: str):
         """
         Run a command as another user.
@@ -535,7 +541,7 @@ class OwnerOnly(vbu.Cog, command_attrs={'hidden': True, 'add_slash_command': Fal
 
     @vbu.command(aliases=['sh'])
     @commands.is_owner()
-    @vbu.bot_has_permissions(send_messages=True)
+    @commands.bot_has_permissions(send_messages=True)
     async def shell(self, ctx: vbu.Context, *, command: str):
         """
         Run a shell command.
@@ -546,7 +552,7 @@ class OwnerOnly(vbu.Cog, command_attrs={'hidden': True, 'add_slash_command': Fal
 
         # Send initial message
         current_data = f"$ {command}\n\n"
-        m = await ctx.send(f"```\n{current_data}```", embeddify=False)
+        m = await ctx.send(f"```\n{current_data}```")
 
         # Woah I do this a few times so let's put it in a function
         async def get_process_data(proc):
@@ -585,7 +591,7 @@ class OwnerOnly(vbu.Cog, command_attrs={'hidden': True, 'add_slash_command': Fal
         pass
 
     @export.command(name="commands")
-    @vbu.bot_has_permissions(send_messages=True, attach_files=True)
+    @commands.bot_has_permissions(send_messages=True, attach_files=True)
     @commands.is_owner()
     async def export_commands(self, ctx: vbu.Context):
         """
@@ -620,7 +626,7 @@ class OwnerOnly(vbu.Cog, command_attrs={'hidden': True, 'add_slash_command': Fal
         await ctx.send(file=discord.File(io.StringIO('\n'.join(lines)), filename="commands.md"))
 
     @export.command(name="guild")
-    @vbu.bot_has_permissions(send_messages=True, attach_files=True)
+    @commands.bot_has_permissions(send_messages=True, attach_files=True)
     @vbu.checks.is_config_set('database', 'enabled')
     @commands.is_owner()
     async def export_guild(self, ctx: vbu.Context, guild_id: typing.Optional[int]):
@@ -708,7 +714,7 @@ class OwnerOnly(vbu.Cog, command_attrs={'hidden': True, 'add_slash_command': Fal
         await ctx.send(file=file)
 
     @export.command(name="table")
-    @vbu.bot_has_permissions(send_messages=True, attach_files=True)
+    @commands.bot_has_permissions(send_messages=True, attach_files=True)
     @vbu.checks.is_config_set('database', 'enabled')
     @commands.is_owner()
     async def export_table(self, ctx: vbu.Context, table_name: str):
