@@ -6,7 +6,6 @@ import discord
 from discord.ext import commands
 
 from .context_embed import Embed
-from .interactions.components import MessageComponents, Button, ButtonStyle, ActionRow
 
 
 class Paginator(object):
@@ -40,8 +39,7 @@ class Paginator(object):
             per_page: int = 10,
             formatter: typing.Callable[
                 ['Paginator', typing.Sequence[typing.Any]], typing.Union[str, discord.Embed, dict]
-            ] = None,
-            remove_reaction: bool = False):
+            ] = None):
         """
         Args:
             data (typing.Union[typing.Sequence, typing.Generator, typing.Callable[[int], typing.Any]]): The
@@ -57,14 +55,16 @@ class Paginator(object):
                 directly into a :func:`discord.Message.edit`.
         """
         self.data = data
-        self.per_page = per_page
-        self.formatter = formatter
-        if self.formatter is None:
+        self.per_page: int = per_page
+        self.formatter: typing.Callable[['Paginator', typing.Sequence[typing.Any]], typing.Union[str, discord.Embed, dict]]
+        if formatter is None:
             self.formatter = self.default_list_formatter
-        self.current_page = None
+        else:
+            self.formatter = formatter
+        self.current_page: int = None
         self._page_cache = {}
 
-        self.max_pages = '?'
+        self.max_pages: int = '?'
         self._data_is_generator = any((
             inspect.isasyncgenfunction(self.data),
             inspect.isasyncgen(self.data),
@@ -105,10 +105,10 @@ class Paginator(object):
         if self.max_pages == 0:
             await ctx.send("There's no data to be shown.")
             return
-        
+
         # Set up our initial components as to not get hit with an UnboundLocalError
         components = self.get_pagination_components()
-        
+
         # Loop the reaction handler
         last_payload = None
         while True:
@@ -123,14 +123,16 @@ class Paginator(object):
             # Format the page data
             payload = self.formatter(self, items)
             if isinstance(payload, discord.Embed):
-                payload = {"embed": payload}
+                payload = {"embeds": [payload]}
             elif isinstance(payload, str):
                 payload = {"content": payload}
+            if (embed := payload.pop("embed", None)):
+                payload.update({"embeds": [embed]})
 
             # Set a default for these things
             payload.setdefault("content", None)
-            payload.setdefault("embed", None)
-            
+            payload.setdefault("embeds", None)
+
             # Work out what components to show
             components = self.get_pagination_components()
 
@@ -176,31 +178,31 @@ class Paginator(object):
         ctx.bot.loop.create_task(self._edit_message(ctx, components=components.disable_components()))
 
     def get_pagination_components(self):
-        components = MessageComponents(
-            ActionRow(
-                Button(
+        components = discord.ui.MessageComponents(
+            discord.ui.ActionRow(
+                discord.ui.Button(
                     label="Start",
                     custom_id="START",
                     disabled=self.current_page == 0,
                 ),
-                Button(
+                discord.ui.Button(
                     label="Previous",
                     custom_id="PREVIOUS",
-                    style=ButtonStyle.SECONDARY,
+                    style=discord.ui.ButtonStyle.SECONDARY,
                     disabled=self.current_page == 0,
                 ),
-                Button(
+                discord.ui.Button(
                     label="Stop",
                     custom_id="STOP",
-                    style=ButtonStyle.DANGER,
+                    style=discord.ui.ButtonStyle.DANGER,
                 ),
-                Button(
+                discord.ui.Button(
                     label="Next",
                     custom_id="NEXT",
-                    style=ButtonStyle.SECONDARY,
+                    style=discord.ui.ButtonStyle.SECONDARY,
                     disabled=self.max_pages != "?" and self.current_page >= self.max_pages - 1,
                 ),
-                Button(
+                discord.ui.Button(
                     label="End",
                     custom_id="END",
                     disabled=self.max_pages == "?" or self.current_page >= self.max_pages - 1,
@@ -243,7 +245,14 @@ class Paginator(object):
         return self._page_cache[page_number]
 
     @staticmethod
-    def default_list_formatter(m, d):
+    def default_list_formatter(m: 'Paginator', d: typing.List[typing.Union[str, discord.Embed]]):
+        """
+        The default list formatter for embeds. Takes the paginator instance and the list of data
+        to be displayed, and returns a dictionary of kwargs for a `Message.edit`.
+        """
+
+        if isinstance(d[0], discord.Embed):
+            return {"embeds": d}
         return Embed(
             use_random_colour=True,
             description="\n".join(d),
@@ -252,7 +261,12 @@ class Paginator(object):
         )
 
     @staticmethod
-    def default_ranked_list_formatter(m, d):
+    def default_ranked_list_formatter(m: 'Paginator', d: typing.List[str]):
+        """
+        The default list formatter for embeds. Takes the paginator instance and the list of strings to be displayed,
+        and returns a dictionary of kwargs for a `Message.edit`.
+        """
+
         return Embed(
             use_random_colour=True,
             description="\n".join([
